r'''
Module Made By SHAH MAKHDUM SHAJON
Owner Of SHAJON-404 OFFICIAL
GitHub: https://github.com/SHAJON-404
Telegram: https://t.me/SHAJON404_OFFICIAL
Facebook: https://www.facebook.com/mdshahmakhdum.shajon
'''
from .jsonxd import *

all = ["fbav", "fbdm", "fbcr", "fblc"]